@@ -1,6 +1,7 @@
 from django.conf import settings
 from django.db import models
 from djangoldp.models import Model
+from djangoldp_circle.models import Circle
 
        
 class Typeevent (Model):
@@ -36,9 +37,10 @@ class Event (Model):
     longDescription = models.TextField(verbose_name="Long description")
     link = models.CharField(max_length=150, blank=True, null=True, verbose_name="Lien internet")
     facebook = models.CharField(max_length=150, blank=True, null=True, verbose_name="Lien Facebook")
+    circle = models.ForeignKey(Circle, null=True, related_name="events")
 
     class Meta : 
-        nested_fields=['type']
+        nested_fields=['type', 'circle']
         ordering = ["startDate"]
         anonymous_perms = ['view', 'add']
         
